=====
PySim
=====

.. start-badges

.. list-table::
    :stub-columns: 1

    * - Ubuntu & macOS
      - | |github| 
    * - Windows
      - | |appveyor|

.. |github| image:: https://github.com/aldebjer/pysim/actions/workflows/main.yml/badge.svg
    :alt: Github Actions Build Status
    :target: https://github.com/aldebjer/pysim/actions/workflows/main.yml

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/aldebjer/pysim?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/aldebjer/pysim

.. end-badges

Pysim is a tool for modeling and simulation of dynamical systems. The systems are described by ordinary differential
equations. There are a number of systems included, and more systems can be added.

For more information on how to use it, build it and extend it please see the
homepage at:

https://pysim.org

or the documentation at: 

https://doc.pysim.org

